import React from "react";
import { Button, ButtonGroup, Spinner, Table } from "react-bootstrap";
import "../styles/Admin.css";
import globals from "../globals";
import AuthenticationGuard from "../components/AuthenticationGuard";
import { apiClient } from "../utils/httpClients";

export default class Admin extends React.Component {
    constructor(props) {
        super(props);
        // Use null to indicate not loaded
        // Use empty array to indicate no items for that state.
        this.state = {
            users: null,
            suspendedUsers: null,
            matches: null,
            user: null,
            currentTab: "matches",
        };
    }

    static contextType = globals;

    async componentDidMount() {
        await this.loadActiveUsers();
        await this.loadSuspendedUsers();
        await this.loadMatches();
    }

    async loadActiveUsers() {
        let response = await apiClient.get("/user/all/active");
        if (response.status === 200) {
            this.setState({ users: response.data.active });
        }
    }

    async loadSuspendedUsers() {
        let response = await apiClient.get("/user/all/suspended");
        if (response.status === 200) {
            this.setState({ suspendedUsers: response.data.suspended });
        } else {
            console.error(response.status);
        }
    }

    async loadMatches() {
        let response = await apiClient.get("/match/all");
        if (response.status === 200) {
            this.setState({ matches: response.data.all });
        }
    }

    DeleteButton() {
        return <Button onClick={() => {
            alert("User deleted.");
        }} variant="outline-secondary">Delete</Button>;

    }

    PardonButton() {
        return <Button onClick={() => {
            alert("User pardoned.");
        }} variant="outline-secondary">Pardon</Button>;

    }

    EditButton() {
        return <Button onClick={() => {
            alert("clicked");
        }} variant="outline-secondary">Edit</Button>;

    }

    userTableHead() {
        return (
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Username</th>
                    <th>Name</th>
                    <th>Email</th>
                    <th>Phone</th>
                    <th></th>
                    <th></th>
                </tr>
            </thead>
        );
    }

    matchTableHead() {
        return (
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Sport</th>
                    <th>Date</th>
                    <th>Location</th>
                    <th></th>
                    <th></th>
                </tr>
            </thead>
        );
    }


    userTableData() {
        if (!this.state.users) {
            return (
                <tr>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                </tr>
            );
        }
        return this.state.users.map((user) => {
            const { _id, firstName, lastName, email, phone } = user;
            return (
                <tr key={_id}>
                    <td>{_id}</td>
                    <td>{firstName}</td>
                    <td>{lastName}</td>
                    <td>{email}</td>
                    <td>{phone}</td>
                    <td>{this.DeleteButton()}</td>
                    <td>{this.EditButton()}</td>
                </tr>
            );
        });
    }

    susUserTableData() {
        if (!this.state.suspendedUsers) {
            return (
                <tr>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                </tr>
            );
        }

        return this.state.suspendedUsers.map((user) => {
            const { _id, firstName, lastName, email, phone } = user;
            return (
                <tr key={_id}>
                    <td>{_id}</td>
                    <td>{firstName}</td>
                    <td>{lastName}</td>
                    <td>{email}</td>
                    <td>{phone}</td>
                    <td>{this.DeleteButton()}</td>
                    <td>{this.EditButton()}</td>
                    <td>{this.PardonButton()}</td>
                </tr>
            );
        });
    }


    matchTableData() {
        if (!this.state.matches) {
            return (
                <tr>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                    <td><Spinner animation="grow" /></td>
                </tr>
            );
        }

        return this.state.matches.map((match) => {
            const { _id, sport, when, location } = match;
            const sportName = sport.name;
            return (
                <tr key={_id}>
                    <td>{_id}</td>
                    <td>{sportName}</td>
                    <td>{when}</td>
                    <td>{location}</td>
                    <td>{this.DeleteButton()}</td>
                    <td>{this.EditButton()}</td>
                    <td>{this.PardonButton()}</td>
                </tr>
            );
        });
    }

    renderTableHead() {
        if (this.state.currentTab === "matches") {
            return this.matchTableHead();
        } else if (this.state.currentTab === "users") {
            return this.userTableHead();
        } else {
            return this.userTableHead();
        }
    }

    renderTableData() {
        if (this.state.currentTab === "matches") {
            return this.matchTableData();
        } else if (this.state.currentTab === "users") {
            return this.userTableData();
        } else {
            return this.susUserTableData();
        }

    }



    render() {
        return (
            <div className="page-root">
                <AuthenticationGuard accessLevel={3}>
                    <React.Fragment>
                        <div className='center'>
                            <h1 id='title'>Administration</h1>
                            <ButtonGroup aria-label="Pages">
                                <Button onClick={() => {
                                    this.setState({ currentTab: "matches" });
                                }} variant="outline-secondary" active={this.state.currentTab === "matches"}>Matches</Button>
                                <Button onClick={() => {
                                    this.setState({ currentTab: "users" });
                                }} variant="outline-secondary" active={this.state.currentTab === "users"}>Users</Button>
                                <Button onClick={() => {
                                    this.setState({ currentTab: "suspended" });
                                }} variant="outline-secondary" active={this.state.currentTab === "suspended"}>Suspended Users</Button>
                            </ButtonGroup>
                        </div>
                        <Table striped bordered hover>
                            {this.renderTableHead()}
                            <tbody>
                                {this.renderTableData()}
                                {/* {this.matchUserTableData()} */}
                            </tbody>
                        </Table>
                    </React.Fragment>
                </AuthenticationGuard >
            </div>
        );
    }
}